@@ -9,9 +9,9 @@ use Log::ger;
 use List::Util qw(shuffle);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-22'; # DATE
+our $DATE = '2022-08-20'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.283'; # VERSION
+our $VERSION = '0.284'; # VERSION
 
 our %SPEC;
 
@@ -397,17 +397,32 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            argv => ['-w', 'MetaSyntactic=theme,dangdut'],
+            summary => 'Select a wordlist with parameters',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             argv => [qw/-l/],
             summary => 'List installed wordlist modules',
             test => 0,
             'x.doc.show_result' => 0,
+            tags => ['category:action-list-installed'],
         },
         {
             argv => [qw/-L/],
             summary => 'List wordlist modules available on CPAN',
             test => 0,
             'x.doc.show_result' => 0,
+            tags => ['category:action-list-cpan'],
+        },
+        {
+            argv => [qw/-s ID::KBBI/],
+            summary => 'Show statistics of a wordlist module',
+            test => 0,
+            'x.doc.show_result' => 0,
+            tags => ['category:action-stat'],
         },
     ],
     'cmdline.default_format' => 'text-simple',
@@ -743,7 +758,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.283 of App::wordlist (from Perl distribution App-wordlist), released on 2022-07-22.
+This document describes version 0.284 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
 
 =head1 SYNOPSIS
 
@@ -826,6 +841,10 @@ Examples:
 
  wordlist(arg => ["/fof[aeiou]/"]);
 
+=item * Select a wordlist with parameters:
+
+ wordlist(wordlists => ["MetaSyntactic=theme,dangdut"]);
+
 =item * List installed wordlist modules:
 
  wordlist(action => "list_installed");
@@ -834,6 +853,10 @@ Examples:
 
  wordlist(action => "list_cpan");
 
+=item * Show statistics of a wordlist module:
+
+ wordlist(arg => ["ID::KBBI"], action => "stat");
+
 =back
 
 This function is not exported.
@@ -993,9 +1016,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
